@@ -8,6 +8,7 @@
 """Invenio module to ease the creation and management of applications."""
 
 
+import subprocess
 from functools import partial
 from pathlib import Path
 
@@ -67,6 +68,37 @@ class AssetsCommands(LocalCommands):
                 status_code=status_code
             )
 
+    @staticmethod
+    def _npm_install_command(path):
+        """Run command and return a ProcessResponse."""
+        status_code = subprocess.call(["npm", "install", "--prefix", path])
+        if status_code == 0:
+            return ProcessResponse(
+                output="Dependent packages installed correctly",
+                status_code=0
+            )
+        else:
+            return ProcessResponse(
+                error=f"Unable to install dependent packages. "
+                      "Got error code {status_code}",
+                status_code=status_code
+            )
+
+    @staticmethod
+    def _build_script(module_pkg):
+        """Run script and return a ProcessResponse."""
+        status_code = module_pkg.run_script("build")
+        if status_code == 0:
+            return ProcessResponse(
+                output="Built correctly",
+                status_code=0
+            )
+        else:
+            return ProcessResponse(
+                error=f"Unable to build. Got error code {status_code}",
+                status_code=status_code
+            )
+
     @staticmethod
     def _assets_link(assets_pkg, module_pkg):
         try:
@@ -108,6 +140,16 @@ class AssetsCommands(LocalCommands):
         assets_pkg = self._assets_pkg()
 
         steps = [
+            FunctionStep(  # Install dependent packages
+                func=self._npm_install_command,
+                args={"path": path},
+                message="Installing dependent packages..."
+            ),
+            FunctionStep(  # Run build script
+                func=self._build_script,
+                args={"module_pkg": module_pkg},
+                message="Building..."
+            ),
             FunctionStep(  # Create link to global folder
                 func=self._run_script,
                 args={"module_pkg": module_pkg},
